@@ -30,7 +30,6 @@
 using KMime::HeaderParsing::parseAddressList;
 using KMime::Types::AddressList;
 using KMime::Types::AddrSpecList;
-using KMime::Types::MailboxList;
 
 using namespace KSieveUi;
 VacationEditWidget::VacationEditWidget(QWidget *parent)
@@ -53,7 +52,7 @@ VacationEditWidget::VacationEditWidget(QWidget *parent)
 
     // Activate checkbox:
     ++row;
-    mActiveCheck = new QCheckBox(i18n("&Activate vacation notifications"), this);
+    mActiveCheck = new QCheckBox(i18nc("@option:check", "&Activate vacation notifications"), this);
     mActiveCheck->setObjectName(QLatin1StringView("mActiveCheck"));
     glay->addWidget(mActiveCheck, row, 0, 1, 2);
     connect(mActiveCheck, &QCheckBox::clicked, this, &VacationEditWidget::setWasChanged);
@@ -207,7 +206,7 @@ VacationEditWidget::VacationEditWidget(QWidget *parent)
 
     // "Send responses also to SPAM mail" checkbox:
     ++row;
-    mSpamCheck = new QCheckBox(i18n("Do not send vacation replies to spam messages"), this);
+    mSpamCheck = new QCheckBox(i18nc("@option:check", "Do not send vacation replies to spam messages"), this);
     mSpamCheck->setObjectName(QLatin1StringView("mSpamCheck"));
     mSpamCheck->setChecked(true);
     glay->addWidget(mSpamCheck, row, 0, 1, 2);
@@ -215,7 +214,7 @@ VacationEditWidget::VacationEditWidget(QWidget *parent)
 
     //  domain checkbox and linedit:
     ++row;
-    mDomainCheck = new QCheckBox(i18n("Only react to mail coming from domain:"), this);
+    mDomainCheck = new QCheckBox(i18nc("@option:check", "Only react to mail coming from domain:"), this);
     mDomainCheck->setObjectName(QLatin1StringView("mDomainCheck"));
     mDomainCheck->setChecked(false);
     connect(mDomainCheck, &QCheckBox::clicked, this, &VacationEditWidget::setWasChanged);
@@ -269,16 +268,13 @@ void VacationEditWidget::setNotificationInterval(int days)
 AddrSpecList VacationEditWidget::mailAliases(bool &ok) const
 {
     QByteArray text = mMailAliasesEdit->text().toLatin1(); // ### IMAA: !ok
-    AddressList al;
+    AddressList addressList;
     const char *s = text.cbegin();
-    AddrSpecList asl;
-    if (parseAddressList(s, text.cend(), al)) {
-        AddressList::const_iterator end(al.constEnd());
-        for (AddressList::const_iterator it = al.constBegin(); it != end; ++it) {
-            const MailboxList &mbl = (*it).mailboxList;
-            MailboxList::const_iterator endJt = mbl.constEnd();
-            for (MailboxList::const_iterator jt = mbl.constBegin(); jt != endJt; ++jt) {
-                asl.push_back((*jt).addrSpec());
+    AddrSpecList addrSpecList;
+    if (parseAddressList(s, text.cend(), addressList)) {
+        for (const auto &address : std::as_const(addressList)) {
+            for (const auto &mail : address.mailboxList) {
+                addrSpecList.push_back(mail.addrSpec());
             }
         }
         ok = true;
@@ -287,7 +283,7 @@ AddrSpecList VacationEditWidget::mailAliases(bool &ok) const
         ok = false;
     }
     mMailAliasesEdit->setInvalidEmail(!ok);
-    return asl;
+    return addrSpecList;
 }
 
 void VacationEditWidget::setMailAliases(const AddrSpecList &aliases)
